@@ -39,7 +39,7 @@ MediaCtrl = wx.media.MediaCtrl
 RichTextCtrl = wx.richtext.RichTextCtrl
 HtmlWindow = wx.html.HtmlWindow
 WebView = wx.html2.WebView
-
+Notebook = wx.Notebook
 
 class Grid(wx.Panel):
     """
@@ -72,4 +72,19 @@ class SVGButton(wx.BitmapButton):
     Wrapper for creating an SVG backed BitmapButton.
     """
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
\ No newline at end of file
+        super().__init__(*args, **kwargs)
+
+
+class NotebookItem(wx.Panel):
+    """
+    Wrapper allowing the specification of Notebook pages
+    as children. e.g.
+
+    ```
+    [Notebook, {on_change: handler},
+      [NotebookItem, {'active': True}
+        [AnyComponent, {...}]],
+      [NotebookItem, {'active': False}
+        [AnyComponent, {...}]]]
+    ```
+    """
